@@ -31,8 +31,9 @@ import os
 from optparse import OptionParser
 import json
 from socket import socket
+from time import sleep
 
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 
 
 def arg_parse():
@@ -40,6 +41,15 @@ def arg_parse():
     arg_list = "-i FILENAME -t TARGETNAME -s GRAPHITE_SERVER [-vh]"
     usage = "Usage: %prog " + arg_list
     parser = OptionParser(usage, version=__version__)
+    parser.add_option("-c", "--cycle", dest="cycle",
+                      action="store_true",
+                      help="run in cycle mode",
+                      default=False)
+    parser.add_option("-n", "--nb-cycle", dest="nb_cycle",
+                      action="store",
+                      type=int,
+                      help="number of cycle",
+                      default=10)
     parser.add_option("-t", "--target", dest="target",
                       help="target name",
                       default=None)
@@ -52,6 +62,10 @@ def arg_parse():
     parser.add_option("-p", "--port", dest="port",
                       help="graphite port",
                       default=2003)
+    parser.add_option("--sleep-time", dest="sleep",
+                      type=int,
+                      help="sleep time in secondes between cycle",
+                      default=30)
     parser.add_option("-v", "--verbose", dest="verbose",
                       action="store_true",
                       help="be verbose",
@@ -190,11 +204,7 @@ def manage(datas):
     return start, stop
 
 
-def main():
-    """Main programm"""
-    options = arg_parse()
-    check_options(options)
-
+def process(options):
     if options.infile is not None:
         if not os.path.exists(options.infile):
             sys.exit(1)
@@ -215,5 +225,23 @@ def main():
     print "Pushed %d datas to graphite server" % nb_data
     print "./manage create_update_bench start=%d stop=%d target=%s" % (start, stop, options.target)
 
+def main():
+    """Main programm"""
+    options = arg_parse()
+    check_options(options)
+
+    if options.cycle:
+        cyc = 0
+        while cyc < options.nb_cycle:
+            print "Cycle %d/%d with sleep time %d" % (cyc + 1,
+                                                      options.nb_cycle,
+                                                      options.sleep)
+            process(options)
+            sleep(options.sleep)
+            cyc += 1
+    else:
+        process(options)
+
+
 if __name__ == '__main__':
     main()
